* CIT_Tunisia_datacleaning.do
* Author: Giorgio_Thiago_Jawhar
* Date: [24_01_24]
* Purpose: Clean and prepare the Tunisia dataset for analysis.


clear all
set max_memory 16g


use "${raw}/dw2022v.dta", clear
 


* Rename original RNE vars

	rename (entident ndgcf d_ouv annee Nentry Exit statut fj rid nationalite) (firmid fiscalid opendate year entry exit status legalform taxregime nationality)

	rename (c_actp nat96 Apen96 NAT09 NAT09_2ch Apenpub09 Delegation Gouvernorat NAT09_3ch) (codeDGI nat96 nat96_2dig nat nat_2dig  nat_INSagg delegation gouvernorat nat_3dig)

	rename (MoyenneS TrancheS Masse_Salariale ExportV ExportP ImportV ImportP CodResult) (employees emp_range wagebill exportvalue exportweight importvalue importweight profitcode)  
    
	rename (CA_TTC_DT CA_Local_DT CA_Export_DT CA_HT_DT) (revenue revenue_domestic revenue_export revenue_beforetax)
	rename (RevenuPP_DT ResultatPM_DT ResultatALL_DT AgeE) (income_owner profits incomeorprofits age)   


* Clean sample

* firm entry and exits /// we start with entry and exit to avoid the artificial entry and exit after dropping years and firms

	destring firmid, gen (fid)

	sort fid year
	xtset fid year


    bys fid: gen lag_year = l.year
	bys fid: gen lead_year = f.year

	gen firm_status = ""

// Identifying entrants

replace firm_status = "entrant" if missing(lag_year) & !missing(year) 

// Identifying exiters

replace firm_status = "exiter" if !missing(lag_year) & missing(lead_year) & year!= 2021

// Identifying stayers - those not classified as entrants or exiters

replace firm_status = "stayer" if firm_status == "" 

** first definition of entry and exit based on presence in previous year 

gen entry1 = 0
replace entry1 = 1 if firm_status == "entrant"
gen exits1 = 0
replace exits1 = 1 if firm_status == "exiter"

** second definition of entry based on age 

gen entry2 = 0
replace entry2 = 1 if age == 1 


* year scope /// 

keep if year > 1999
tab year
gen scope = (year < 2019) & (year>2008)

* tax regime /// focus on CIT

gen tax_sample = (taxregime == "4"|taxregime == "5"|taxregime == "6")
tab tax_sample

* keep only observations between 2009 and 2018 that pays CIT

keep if (scope==1 & tax_sample==1)

* keep only private firms 

keep if status == "1"

* drop non incorporated firms 

drop if legalform =="99"

* activity/// drop never active firms in the dataset

gen active = max(employees,revenue_beforetax,wagebill,njc,exportvalue,importvalue, revenue_export,incomeorprofits,revenue) > 0 ///
		  &  max(employees,revenue_beforetax,wagebill,njc,exportvalue,importvalue, revenue_export,incomeorprofits,revenue) != .
bys firmid: gen inactive_all = sum(active) == 0
gen never_active = (inactive_all == 1)

tab never_active 
sum if never_active == 1 
drop if never_active == 1  

* Correct wrong nat classifications

rename nat old_nat
gen nat = old_nat

*correct nat code


* Situation 
gen x4 = substr(nat,4,1)
gen x3 = substr(nat,3,1)
gen x2 = substr(nat,2,1)
gen x1 = substr(nat,1,1)
gen x_pos = strpos(nat,"X")
tab x_pos
drop x_pos

* correction 
** correct the "---X" 

forvalues i = 1/16 {
bys firmid: replace nat= nat[_n-`i'] if !missing(nat[_n-`i']) & nat_3dig==nat_3dig[_n-`i'] & x4 == "X" & x4[_n-`i'] !="X"
}
forvalues i = 1/16 {
bys firmid: replace nat= nat[_n+`i'] if !missing(nat[_n+`i']) & nat_3dig==nat_3dig[_n+`i'] & x4 == "X" & x4[_n+`i'] !="X"
}

drop x1 x2 x3 x4 

** correct the "--XX"

gen x3 = substr(nat,3,2)
forvalues i = 1/16 {
bys firmid: replace nat= nat[_n-`i'] if !missing(nat[_n-`i']) & nat_2dig==nat_2dig[_n-`i'] & x3 == "XX" & x3[_n-`i'] !="XX"
}
forvalues i = 1/16 {
bys firmid: replace nat= nat[_n+`i'] if !missing(nat[_n+`i']) & nat_2dig==nat_2dig[_n+`i'] & x3 == "XX" & x3[_n+`i'] !="XX"
}
drop x3 

** correct the "XXXX" 

gen x1 = substr(nat,1,4)
forvalues i = 1/16 {
bys firmid: replace nat= nat[_n-`i'] if !missing(nat[_n-`i'])  & x1 == "XXXX" & x1[_n-`i'] !="XXXX"
}
forvalues i = 1/16 {
bys firmid: replace nat= nat[_n+`i'] if !missing(nat[_n+`i']) & x1 == "XXXX" & x1[_n+`i'] !="XXXX"
}
drop x1 

** correcting some X manually and combining some sectors 

replace nat = "2351" if nat =="235X"
replace nat = "2351" if nat =="2352"

replace nat = "4211" if nat =="421X"
replace nat = "0143" if nat =="014X"

replace nat = "0321" if nat =="032X"
replace nat = "0321" if nat =="0322"

replace nat = "2229" if nat =="222X"

replace nat = "6511" if nat =="6512"
replace nat = "6511" if nat =="6520"

replace nat = "6120" if nat =="6110"

gen x_pos = strpos(nat,"X")
tab x_pos

/* prepare EU data 2dig 

preserve 
clear all
use "${raw}/EU_TUN_WLD.dta"
gen nat_2dig = substr(nat,1,2) 
encode nat_2dig, generate(ind2dig)
collapse (sum) EU_WLD, by(year ind2dig)
sort ind2dig year
save "EU_W_2dig.dta", replace
restore
*/ 

* merge EU import data 

sort nat year 
merge m:1 nat year using "${raw}/EU_TUN_WLD.dta"
drop if _merge == 2
drop _merge
 

save "${intermediate}/dw2022_CIT_inter.dta", replace

*log close
