* CIT_variables_gen.do
* Author: Giorgio_Thiago_Jawhar
* Date: [24_01_24]
* Purpose: Generate variables.


use "${intermediate}/dw2022_CIT_inter.dta", clear

* Generate variables 
* Encode nat classification

destring nat_2dig, generate(ind2dig) force
destring nat_3dig, generate(ind3dig) force
destring nat, generate(ind4dig) force

* Foreign firms

gen foreign=(nationality=="002")

* Entry /// INS variable

gen entry_d=(entry=="1")

* Exit /// INS variable

gen exit_d=(exit=="1")

* Year of incorporation 

gen yearincorp=substr(opendate,1,4)
destring yearincorp,replace

* Tax regimes 

gen cit_general=(taxregime=="4")
gen cit_eson_art46=(taxregime=="5")
gen cit_offshore=(taxregime=="6")

gen cit_10pct_art49=(taxregime=="4" & (nat=="1342"|nat=="1397"|nat=="1415"|nat=="1522"|nat=="1629"|nat=="2342"|nat=="2595"|nat=="01"|nat=="02"|nat=="0311"|nat=="0322"|(nat=="47" & legalform=="30")))
gen cit_35pct_art49=(taxregime=="4" & (nat_2dig=="64"|nat_2dig=="65"|nat_2dig=="66"|nat_2dig=="61"|nat_2dig=="06"|nat_3dig=="091"|nat_3dig=="192"|nat=="1920"))


* Firm count 

gen nfirms = 1
gen noffshore = 1 if cit_offshore == 1 

* Employment definition corrections 

* new_employees : change zero with missing 

drop employees
egen employees = rowmean(EffectifST1 EffectifST2 EffectifST3 EffectifST4)

* Generate missing tax, and tax anomaly variables

bys fid year : gen tax_missing = 0 if revenue_beforetax !=. | profits !=. 
bys fid year : replace tax_missing = 1 if revenue_beforetax ==. & max(employees,wagebill,exportvalue,importvalue) !=. & max(employees,wagebill,exportvalue,importvalue) != 0
bys fid year : gen tax_anomaly = 0 if max(exportvalue,revenue_beforetax,importvalue,wagebill) !=. & revenue_beforetax !=.
bys fid year: replace tax_anomaly = 1 if (exportvalue > revenue_beforetax & exportvalue!=. & revenue_beforetax !=.) | (importvalue > revenue_beforetax & importvalue!=. & revenue_beforetax !=.) | (wagebill > revenue_beforetax & wagebill!=. & revenue_beforetax !=.)

* label varibles

label variable revenue_beforetax "Revenue (Million Dinars)"
label variable wagebill 		 "Wagebill (Million Dinars)"
label variable profits 			 "Profits (Million Dinars)"
label variable exportvalue 		 "Customs export value (Million Dinars)"
label variable importvalue 		 "Customs import value (Million Dinars)"
label variable revenue_export 	 "DGI export value (Million Dinars)"
label variable employees 		 "Number of employees"
label variable age 				 "firm age"
label variable cit_offshore 	 "Offshore dummy"
label variable entry_d 			 "Entry dummy"
label variable exit_d 			 "Exit dummy"
label variable exportweight 	 "Customs export quantity (Ton)"
label variable importweight 	 "Customs import quantity (Ton)"

** Aggregate sectors

gen sector_group = ""

replace sector_group = "1. Agriculture, Forestry, Fishing, and Mining" if inlist(nat_2dig, "01", "02", "03", "06", "07", "08", "09")
replace sector_group = "2. Manufacturing and Construction" if inlist(nat_2dig, "10", "11", "12", "13", "14", "15", "16", "17", "18")
replace sector_group = "2. Manufacturing and Construction" if inlist(nat_2dig, "19", "20", "21", "22", "23", "24", "25", "26", "27")
replace sector_group = "2. Manufacturing and Construction" if inlist(nat_2dig, "28", "29", "30", "31", "32", "33")
replace sector_group = "2. Manufacturing and Construction" if inlist(nat_2dig, "37", "38","41", "42", "43")
replace sector_group = "3. Wholesale, Retail, and Transportation" if inlist(nat_2dig, "45", "46", "47", "49", "50", "51", "52", "53")
replace sector_group = "4. Financial, Real Estate, and Professional Services" if inlist(nat_2dig, "58", "59", "60", "61", "62", "63", "64", "65")
replace sector_group = "4. Financial, Real Estate, and Professional Services" if inlist(nat_2dig, "66", "68", "69", "70", "71", "72", "73", "74")
replace sector_group = "4. Financial, Real Estate, and Professional Services" if inlist(nat_2dig, "77","78", "79", "80", "81", "82", "55", "56")
replace sector_group = "5. Public Services, Education, and Health" if inlist(nat_2dig, "84", "85", "86", "87", "88")
replace sector_group = "6. Arts, Recreation, and Other Services" if inlist(nat_2dig, "90", "91", "92", "93", "95", "96")

* Handle the unclassified category

replace sector_group = "Unclassified/Unknown" if nat_2dig == "XX" | nat_2dig == ""
encode sector_group, gen(sector_group_num)

gen d_manufacturing = sector_group_num == 2
gen d_sales         = sector_group_num == 3
gen d_services      = sector_group_num == 4
********************************************************************************
** Transformations**************************************************************
** logs

gen ln_output=ln(revenue_beforetax)
gen ln_employees=ln(employees)
gen ln_wb=ln(wagebill)

*EU exports

gen ln_EU_W = ln(EU_WLD)
gen ln_EU_int = ln_EU_W * cit_offshore

**IHS

gen ihs_employees =(employees+(employees^2+1)^.5) 
gen ln_prof=ln(profits+(profits^2+1)^.5)
*replace exportvalue=0 if exportvalue==.
*replace importvalue=0 if importvalue==. 
gen ln_expv=ln(exportvalue+(exportvalue^2+1)^.5)  
gen ln_impv=ln(importvalue+(importvalue^2+1)^.5)  
gen ln_revenueEXP=ln(revenue_export+(revenue_export^2+1)^.5)
gen ln_revenueD=ln(revenue_domestic+(revenue_domestic^2+1)^.5)

winsor2 profits, cuts(1 99) by(year)
gen ln_prof_w=ln(profits_w+(profits_w^2+1)^.5)

** employment dummy variables 

gen employees_2_or_more =  employees >=2  if employees != .
gen employees_5_or_more =  employees >=5  if employees != .
gen employees_10_or_more = employees >=10 if employees != .
gen employees_50_or_more = employees >=50 if employees != .

*** export dummies
gen d_exportvalue    = exportvalue    != . & exportvalue > 0
gen d_revenue_export = revenue_export != . & revenue_export > 0

gen d_employment = employees != . & employees > 0
gen d_wagebill   = wagebill != . & wagebill > 0
** under reporting 

gen ln_ur=ln_expv-ln_revenueEXP

** other variables

gen ln_w=ln(wagebill/employees)
gen ln_labprod=ln(revenue_beforetax/employees) if revenue_beforetax!=. & revenue_beforetax>0


gen lnage=ln(1+age)
gen age2=(age)^2
egen size=group(emp_range) 
 
gen young=(age<5)
gen small=(emp_range=="00"|emp_range=="01"|emp_range=="02")
gen nopay=(profits<=0 & profits!=.)

* correct abnormalities
drop if age<0


***Year firms entry in new offshore regime
gen entry_year = .
replace entry_year =  2014 if (yearincorp <= 2004 | yearincorp >= 2014 & yearincorp != .)
replace entry_year =  2014 + 10 - (2014 - yearincorp) if inrange(yearincorp, 2005,2013)
replace entry_year =  . if cit_offshore == 0

/*
sum profits, d 
winsor2 profits, cuts(1 100)

sum ln_output,d
winsor2 ln_output, cuts(1 99)
*/

** correct units
 
 foreach var of varlist revenue_beforetax profits exportvalue importvalue revenue_export {
 	replace `var' = `var'/1000000
	
 }
 
 foreach var of varlist exportweight importweight {
 	replace `var' = `var'/1000
	
 }

 replace wagebill = wagebill/1000000000 /// wage bill is in millimes not dinars
 
 gen d_loss = (profits < 0) if profits != .
 gen profit_margin = profits/revenue_beforetax
 
 * ---- Define Active Firms Based on Various Criteria ----

* First Definition: Firms declaring some revenue or employment

gen active_firm = (revenue_beforetax !=. | employees !=.)
tab active_firm

* Second Definition: Firms with positive revenue or employment

gen active_firm2 = (revenue_beforetax > 0 | employees > 0)
tab active_firm2

* Third Definition: Firms with positive revenue and non-missing employment

gen active_firm3 = (revenue_beforetax > 0 & revenue_beforetax !=.) | (employees > 0 & employees !=.)
tab active_firm3
 
/** check firms with  missing employees and positive wage bill 

gen tag = 1 if wagebill > 0 & employees == . & wagebill !=.
tab tag
/*
        tag |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |      1,959      100.00      100.00
------------+-----------------------------------
      Total |      1,959      100.00
 
*/
gen tag2 = 1 if wagebill > 0 & employees == 0 & wagebill !=.

/*

       tag2 |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |      2,481      100.00      100.00
------------+-----------------------------------
      Total |      2,481      100.00
*/
drop tag tag2


gen tag3 = 0 
replace tag3 = 1 if (EffectifST1 == 0 | EffectifST1 == .) & SalairesT1>0 & SalairesT1 !=.
replace tag3 = 1 if (EffectifST2 == 0 | EffectifST2 == .) & SalairesT2>0 & SalairesT2 !=.
replace tag3 = 1 if (EffectifST3 == 0 | EffectifST3 == .) & SalairesT3>0 & SalairesT3 !=.
replace tag3 = 1 if (EffectifST4 == 0 | EffectifST4 == .) & SalairesT4>0 & SalairesT4 !=.

bys fid: egen tag_all = max(tag3)

/*

       tag3 |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |    740,766       96.30       96.30
          1 |     28,475        3.70      100.00
------------+-----------------------------------
      Total |    769,241      100.00
*/
*/

save "${final}/dw2022_CIT_clean.dta", replace

* drop firms switching offshore status after 2014

bys fid : egen flag = mean(cit_offshore) 
drop if flag > 0 & flag < 1 

* drop firms switching ind2dig before 2013 

bys fid: gen sector_change = ind2dig != ind2dig[_n-1] if _n>1 
drop if sector_change ==1 & year >= 2013

* balancing the panel 
 
    bys fid: gen nobs = _N
	tab nobs
	
// 	unique fid
// 	unique fid if nobs == 10 
// 	unique fid if nobs == 9 
// 	unique fid if nobs == 8 
//     unique fid if nobs == 7 
//     unique fid if nobs == 6 
//     unique fid if nobs == 5 

gen balanced_firms = (nobs == 10)

save "${final}/dw2022_CIT_firmlevel.dta", replace


