* CIT_descriptive_stats.do
* Author: Giorgio_Thiago_Jawhar
* Date: [24_01_24]
* Purpose: Generate descriptive statistics.



* load data
use "${final}/dw2022_CIT_clean.dta", clear

***** TABLE 1a: DESCRIPTIVE STATISTICS YEAR *****

* Labeling variables
label variable cit_offshore "Offshore Dummy"
label variable foreign "Foreign Dummy"
label variable age "Age"
label variable d_manufacturing "Manufacturing Dummy"
label variable d_sales "Sales Dummy"
label variable d_services "Services Dummy"
label variable entry_d "Entry Dummy"
label variable exit_d "Exit Dummy"
label variable d_employment "Employment Dummy"
label variable employees "Employees"
label variable d_wagebill "Wagebill Dummy"
label variable wagebill "Wagebill, M dinars"
label variable revenue_beforetax "Revenue Before Tax, M dinars"
label variable profits "Profits, M dinars"
label variable d_revenue_export "Exports Dummy"
label variable revenue_export "Exports"
label variable d_exportvalue "Exports Customs Dummy"
label variable exportvalue "Exports Customs, M dinars"
label variable importvalue "Imports Customs"
label variable tax_anomaly "Tax Anomaly Dummy"
label variable tax_missing "Tax Missing Dummy"
 
/***** TABLE 1a:

global descript cit_offshore foreign age d_manufacturing d_sales d_services entry_d exit_d d_employment employees d_wagebill wagebill revenue_beforetax profits d_revenue_export revenue_export  d_exportvalue exportvalue importvalue 
eststo drop *
eststo stats_all: quietly estpost summarize $descript ,d
eststo stats_12: quietly estpost summarize $descript if year == 2012,d
eststo stats_14: quietly estpost summarize $descript if year == 2014,d
eststo stats_16: quietly estpost summarize $descript if year == 2016,d
 
esttab stats_all stats_12 stats_14 stats_16 using "${tables}/descriptive_stats/table_descriptive1_updated.tex", ///
	refcat(cit_offshore "Firm Characteristics:" d_employment "Social Security Records Outcomes:" revenue_beforetax "Tax Record Outcomes:"  d_exportvalue "Customs Records Outcomes:", nolabel) ///
	cells("mean(fmt(2))" "sd(fmt(2) par)") mtitles("Panel" "2012" "2014" "2016") nonum ///
	label replace f booktabs brackets gap ///
	starlevels(* 0.1 ** 0.05 *** 0.01) collabels(none)

***** TABLE 1b: DESCRIPTIVE STATISTICS OFFSHORE V ONSHORE *****
eststo drop *
eststo stats_cit0: quietly estpost summarize $descript if year == 2013 & cit_offshore == 0,d
eststo stats_cit1: quietly estpost summarize $descript if year == 2013 & cit_offshore == 1,d

esttab stats_cit0 stats_cit1 using "${tables}/descriptive_stats/table_descriptive_regime_updated.tex", ///
	refcat(cit_offshore "Firm Characteristics:" d_employment "Social Security Records Outcomes:" revenue_beforetax "Tax Record Outcomes:"  d_exportvalue "Customs Records Outcomes:", nolabel) ///
	cells("mean(fmt(2))" "sd(fmt(2) par)") mtitles("Onshore" "Offshore") nonum ///
	label replace f booktabs brackets gap ///
	starlevels(* 0.1 ** 0.05 *** 0.01) collabels(none)
*/

*** Combined TABLE 1a & 1b: 

global descript cit_offshore foreign age d_manufacturing d_sales d_services entry_d exit_d d_employment employees d_wagebill wagebill revenue_beforetax profits d_revenue_export revenue_export  d_exportvalue exportvalue importvalue 
eststo drop *
eststo stats_all: quietly estpost summarize $descript ,d
eststo stats_12: quietly estpost summarize $descript if year == 2012,d
eststo stats_14: quietly estpost summarize $descript if year == 2014,d
eststo stats_16: quietly estpost summarize $descript if year == 2016,d
eststo stats_cit0: quietly estpost summarize $descript if year == 2013 & cit_offshore == 0,d
eststo stats_cit1: quietly estpost summarize $descript if year == 2013 & cit_offshore == 1,d

esttab stats_all stats_12 stats_cit0 stats_cit1 stats_14 stats_16 using "${tables}/descriptive_stats/table_descriptive1_updated.tex" , ///
	refcat(cit_offshore "Firm Characteristics:" d_employment "Social Security Records Outcomes:" revenue_beforetax "Tax Record Outcomes:"  d_exportvalue "Customs Records Outcomes:", nolabel) ///
	cells("mean(fmt(2))" "sd(fmt(2) par)") mtitles("Panel" "2012" "Onshore 2013" "Offshore 2013" "2014" "2016" ) nonum ///
	label replace f booktabs brackets gap ///
	starlevels(* 0.1 ** 0.05 *** 0.01) collabels(none)
 	
*****histogram of entry year
histogram entry_year if year == 2013 & cit_offshore == 1, bin(10) xtitle("Year firms lose benefit")
graph export "${figures}/descriptive_stats/hist_enteryear.png", replace 

***** TABLE 1c: TABLE WITH TOTALS*****
preserve

	* Collapse data for graphing

	collapse (sum) nfirms noffshore employees wagebill exportvalue importvalue revenue_beforetax profits revenue_export , by(year)

	sort year

	export delimited using "${tables}/aggregates_year.csv", replace

restore 


* ---- GRAPHS ----

* Preserve data for graph generation

preserve

	* Collapse data for graphing
	 * Collapse data for graphing
	 global tax_vars "nfirms noffshore active_firm3 employees wagebill exportvalue exportweight importvalue importweight revenue_beforetax profits revenue_export entry_d exit_d age tax_anomaly tax_missing"

	 collapse (sum) $tax_vars , by(year cit_offshore)
	 
	 label variable nfirms "Total Number of Firms"
	label variable noffshore "Total Number Offshore Firms"
	label variable active_firm3 "Total Active Firms"
	label variable employees "Total Number of Employees"
	label variable wagebill "Total Wage Bill"
	label variable exportvalue "Total Export Value"
	label variable exportweight "Total Export Weight"
	label variable importvalue "Total Import Value"
	label variable importweight "Total Import Weight"
	label variable revenue_beforetax "Total Revenue Before Tax"
	label variable profits "Total Profits"
	label variable revenue_export "Total Export Revenue"
	label variable entry_d "Total Entries"
	label variable exit_d "Total Exits"
	label variable age "Total Age"
	label variable tax_anomaly "Total Tax Anomaly"
	label variable tax_missing "Total Tax Missing"


	* Generate normalized variables for graphing

	sort year 
	foreach var of varlist $tax_vars {
		gen aux_`var'2013 = `var' if year == 2013
		bys cit_offshore: egen aux_ref = max(aux_`var'2013)
		gen `var'_norm = `var'/aux_ref
		drop aux_ref
	}

	sort year

	* Generate graphs for each variable
	foreach var of varlist $tax_vars {
	local var_label : variable label `var'

	twoway (scatter `var'_norm year if cit_offshore == 1 , c(l) lc(dknavy) mc(dknavy)) ///
		   (scatter `var'_norm year if cit_offshore == 0, c(l) lc(dkgreen) mc(dkgreen)), xline(2013, lp(dash)) ///
		   graphregion(color(white)) legend(lab(1 "Offshore") lab(2 "Onshore")) ///
		   ytitle("`var_label'", size(medsmall))
		   graph export "${figures}/descriptive_stats/`var'.png", replace
		
	   twoway (scatter `var' year if cit_offshore == 1 , c(l) lc(dknavy) mc(dknavy)) ///
	   (scatter `var' year if cit_offshore == 0, c(l) lc(dkgreen) mc(dkgreen)), xline(2013, lp(dash)) ///
	   graphregion(color(white)) legend(lab(1 "Offshore") lab(2 "Onshore")) ///
	   ytitle("`var_label'", size(medsmall)) 
	   graph export "${figures}/descriptive_stats/levels_`var'.png", replace
	}

* Restore data to original state
restore 


* ---- Analysis of Firm Composition by Offshore Status, Sector, and Year ----

* Preserve the original dataset

preserve

* Collapse the dataset to summarize by year, offshore status, and sector group
collapse (sum) nfirms active_firm3 employees wagebill revenue_beforetax, by(year cit_offshore sector_group_num)

* Labeling the collapsed variables for clarity
label variable nfirms "Total Number of Firms"
label variable active_firm3 "Total Number of Active Firms"
label variable employees "Total Number of Employees"
label variable wagebill "Total Wage Bill"
label variable revenue_beforetax "Total Revenue Before Tax"

* Calculating shares and average size
foreach var of varlist nfirms employees revenue_beforetax {
    bys year cit_offshore: egen tot_`var' = sum(`var')
    gen share_`var' = `var'/tot_`var'
}

gen avg_size = revenue_beforetax/nfirms

* Plotting share of firms by sector for offshore entities
twoway (scatter share_nfirms year if sector_group_num == 2 & cit_offshore == 1, c(l) lc(dknavy) mc(dknavy)) ///
       (scatter share_nfirms year if sector_group_num == 3 & cit_offshore == 1, c(l) lc(dkgreen) mc(dkgreen)) ///
       (scatter share_nfirms year if sector_group_num == 4 & cit_offshore == 1, c(l) lc(dkorange) mc(dkorange)), xline(2013, lp(dash)) ///
       graphregion(color(white)) legend(lab(1 "Manufacturing") lab(2 "Sales") lab(3 "Services")) ///
       ytitle("Share of Total Firms")
graph export "${figures}/descriptive_stats/sector_comp_firms_offshore.png", replace

* Plotting share of employees by sector for offshore entities
twoway (scatter share_employees year if sector_group_num == 2 & cit_offshore == 1, c(l) lc(dknavy) mc(dknavy)) ///
       (scatter share_employees year if sector_group_num == 3 & cit_offshore == 1, c(l) lc(dkgreen) mc(dkgreen)) ///
       (scatter share_employees year if sector_group_num == 4 & cit_offshore == 1, c(l) lc(dkorange) mc(dkorange)), xline(2013, lp(dash)) ///
       graphregion(color(white)) legend(lab(1 "Manufacturing") lab(2 "Sales") lab(3 "Services")) ///
       ytitle("Share of Total Employees")
graph export "${figures}/descriptive_stats/sector_comp_emp_offshore.png", replace

* Plotting share of revenue before tax by sector for offshore entities
twoway (scatter share_revenue_beforetax year if sector_group_num == 2 & cit_offshore == 1, c(l) lc(dknavy) mc(dknavy)) ///
       (scatter share_revenue_beforetax year if sector_group_num == 3 & cit_offshore == 1, c(l) lc(dkgreen) mc(dkgreen)) ///
       (scatter share_revenue_beforetax year if sector_group_num == 4 & cit_offshore == 1, c(l) lc(dkorange) mc(dkorange)), xline(2013, lp(dash)) ///
       graphregion(color(white)) legend(lab(1 "Manufacturing") lab(2 "Sales") lab(3 "Services")) ///
       ytitle("Share of Revenue Before Tax")
graph export "${figures}/descriptive_stats/sector_comp_revenue_offshore.png", replace

* Plotting average size of firms by revenue before tax in offshore entities by sector
twoway (scatter avg_size year if sector_group_num == 2 & cit_offshore == 1, c(l) lc(dknavy) mc(dknavy)) ///
       (scatter avg_size year if sector_group_num == 3 & cit_offshore == 1, c(l) lc(dkgreen) mc(dkgreen)) ///
       (scatter avg_size year if sector_group_num == 4 & cit_offshore == 1, c(l) lc(dkorange) mc(dkorange)), xline(2013, lp(dash)) ///
       graphregion(color(white)) legend(lab(1 "Manufacturing") lab(2 "Sales") lab(3 "Services")) ///
       ytitle("Average Revenue Size")
graph export "${figures}/descriptive_stats/sector_comp_avgrevenue_offshore.png", replace

restore

* ---- Sector-Specific Analysis: Manufacturing and Construction ----

preserve

	collapse (sum) $tax_vars if sector_group_num == 2, by(year cit_offshore)

	* Normalize and plot sector-specific data

	sort year

	foreach var in $tax_vars {
		gen aux_`var'2013 = `var' if year == 2013
		bys cit_offshore: egen aux_ref = max(aux_`var'2013)
		gen `var'_norm = `var'/aux_ref
		drop aux_ref
		}

	sort year
	foreach var in $tax_vars {	
		
		twoway (scatter `var'_norm year if cit_offshore == 1 , c(l) lc(dknavy) mc(dknavy)) ///
			   (scatter `var'_norm year if cit_offshore == 0, c(l) lc(dkgreen) mc(dkgreen)), xline(2013, lp(dash)) ///
			   graphregion(color(white)) legend(lab(1 "Offshore") lab(2 "Onshore")) ///
			   title("Line graph of manufacturing `var' over years")
			   graph export "${figures}/descriptive_stats/`var'_manu_Years.png", replace
			   
		 twoway (scatter `var' year if cit_offshore == 1 , c(l) lc(dknavy) mc(dknavy)) ///
		   (scatter `var' year if cit_offshore == 0, c(l) lc(dkgreen) mc(dkgreen)), xline(2013, lp(dash)) ///
		   graphregion(color(white)) legend(lab(1 "Offshore") lab(2 "Onshore"))
		   graph export "${figures}/descriptive_stats/`var'_manu_Years_levels.png", replace
			   }
restore


* ---- BIG FIRM QNQLYSIS ----

preserve
	
	keep if inlist(year, 2013,2015)
	
	bys year cit_offshore: egen tot_revenue = sum(revenue_beforetax)
	gen sh = revenue_beforetax/tot_revenue
	
	gsort year cit_offshore -sh
	bys year cit_offshore: gen rank = _n
	
	recode rank (1/100 = 1) (101/1000 = 2) (1001/6000  = 3), gen(rank_bin)
	
	*graph  bar  (sum) sh if year == 2013 & cit_offshore  == 1, over(rank_bin )
restore

* ************************ OFFSHORE PARTICIPATION **************************************

* Collapse indicators for all firms
global vars_part "nfirms employees wagebill exportvalue revenue_beforetax profits"
preserve 
	collapse (sum) $vars_part , by(year cit_offshore)
	foreach var of varlist $vars_part  {
		egen tot_`var' = sum(`var'), by(year)
		gen sh_`var' = `var'/tot_`var'
		label var sh_`var' "Share of `var'"
	}
	drop if cit_offshore == 0
	gen manuf = 0
	label var manuf "Manufacturing Sector Indicator"
	tempfile all
	save "`all'"
restore

preserve
	* Collapse indicators for manufacturing sector only
	keep if sector_group_num == 2
	collapse (sum) $vars_part , by(year cit_offshore)
	foreach var of varlist $vars_part  {
		egen tot_`var' = sum(`var'), by(year)
		gen sh_`var' = `var'/tot_`var'
	}
	drop if cit_offshore == 0
	gen manuf = 1

	append using "`all'"

	* Plotting Results

	* Share of Firms
	twoway (connect sh_nfirms year if manuf == 0, lc(dknavy) lw(medthick) mc(dknavy)) ///
			(connect sh_nfirms year if manuf == 1, lc(dkorange) lw(medthick) mc(dkorange)), ///
		graphregion(color(white)) xline(2013.5, lp(dash)) ylab(0(.05).45, glp(dash)) ///
		legend(off) text(.22 2015 "All firms", size(small) c(dknavy)) ///
		text(.35 2015 "Manufacturing", size(small) c(dkorange)) ytitle("Share of Firms")
	graph export "${figures}/descriptive_stats/nfirms_share.png", as(png) replace

	* Share of Employment
	twoway (connect sh_employees year if manuf == 0, lc(dknavy) lw(medthick) mc(dknavy)) ///
			(connect sh_employees year if manuf == 1, lc(dkorange) lw(medthick) mc(dkorange)), ///
		graphregion(color(white)) xline(2013.5, lp(dash)) ylab(0.1(.1).7, glp(dash)) ///
		legend(off) text(.42 2015 "All firms", size(small) c(dknavy)) ///
		text(.65 2015 "Manufacturing", size(small) c(dkorange))  ytitle("Share of Employment")
	graph export "${figures}/descriptive_stats/employees_share.png", as(png) replace
		
	* Share of Turnover
	twoway (connect sh_revenue_beforetax year if manuf == 0, lc(dknavy) lw(medthick) mc(dknavy)) ///
			(connect sh_revenue_beforetax year if manuf == 1, lc(dkorange) lw(medthick) mc(dkorange)), ///
		graphregion(color(white)) xline(2013.5, lp(dash)) ylab(0.1(.1).5, glp(dash)) ///
		legend(off) text(.21 2015 "All firms", size(small) c(dknavy)) ///
		text(.45 2015 "Manufacturing", size(small) c(dkorange))    ytitle("Share of Turnover")
	graph export "${figures}/descriptive_stats/revenue_share.png", as(png) replace	
		
	* Share of Export Value
	twoway (connect sh_exportvalue year if manuf == 0, lc(dknavy) lw(medthick) mc(dknavy)) ///
			(connect sh_exportvalue year if manuf == 1, lc(dkorange) lw(medthick) mc(dkorange)), ///
		graphregion(color(white)) xline(2013.5, lp(dash)) ylab(0.5(.1).9, glp(dash)) ///
		legend(off) text(.83 2016 "All firms", size(small) c(dknavy)) ///
		text(.89 2016 "Manufacturing", size(small) c(dkorange))   ytitle("Share of Exports")
	graph export "${figures}/descriptive_stats/exportvalue_share.png", as(png) replace	
restore



preserve
	keep if year == 2013
	bys cit_offshore: gen N = _N
	tab cit_offshore
	
	cap mat drop top_result
	foreach var of varlist employees revenue_beforetax revenue_export {
	
		gsort cit_offshore -`var'
		by cit_offshore: gen rank_`var' = _n
		gen top10_`var' = (rank_`var' < 0.1*N)
		gen top1_`var' =  (rank_`var' < 0.01*N)
		
		summ `var' if cit_offshore == 1
		loc t_off = r(sum)
		summ `var' if cit_offshore == 0
		loc t_ons = r(sum)
		summ `var' if cit_offshore == 1 & top10_`var' == 1
		loc t_off_top10 = r(sum)
		summ `var' if cit_offshore == 0 & top10_`var' == 1
		loc t_ons_top10 = r(sum)
		summ `var' if cit_offshore == 1 & top1_`var' == 1
		loc t_off_top1 = r(sum)
		summ `var' if cit_offshore == 0 & top1_`var' == 1
		loc t_ons_top1 = r(sum)
		
		mat top_result = nullmat(top_result) \ `t_off_top10'/`t_off', `t_ons_top10'/`t_ons', `t_off_top1'/`t_off', `t_ons_top1'/`t_ons'
		
	
	}
	
	clear
	svmat top_result 
	
	export delimited using "${tables}/top_shares.csv", replace
	
restore

* this does not run with the synthetic data commenting it out
/*
*****TOP 1
preserve
	keep if cit_offshore == 1
	
	gsort year -employees
	bys year: gen N = _N
	bys year: gen rank = _n
	gen top1 =  (rank < 0.01*N)
	replace top1 = . if year != 2013
	bys fid: egen rank_2013 = mean(top1)
	replace rank_2013 = 0 if rank_2013 == .
	
	collapse (sum) employees (count) fid, by(year rank_2013)
	
	reshape wide employees fid, i(year) j(rank_2013)
	
	gen sh = employees1/(employees0 + employees1)
	
	twoway scatter sh year, c(l) ylabel(0(.1).5) xline(2013)
	graph export "${figures}/descriptive_stats/top1_part.png", as(png) replace	
	
restore
*/

*****TOP 1
preserve
	keep if cit_offshore == 1
	
	gsort year -employees
	bys year: gen N = _N
	bys year: gen rank = _n
	gen top1 =  (rank < 0.1*N)
	replace top1 = . if year != 2013
	bys fid: egen rank_2013 = mean(top1)
	replace rank_2013 = 0 if rank_2013 == .
	
	collapse (sum) employees (count) fid, by(year rank_2013)
	 list
	reshape wide employees fid, i(year) j(rank_2013)
	
	gen sh = employees1/(employees0 + employees1)
	
	twoway scatter sh year, c(l) ylabel(0(.1)1) xline(2013)
	graph export "${figures}/descriptive_stats/top10_part.png", as(png) replace	
	
restore

* this does not run with the synthetic data commenting it out
/*
preserve

	gsort year cit_offshore -employees
	bys year cit_offshore: gen N = _N
	bys year cit_offshore: gen rank = _n
	gen top1 =  (rank < 0.01*N)
	replace top1 = 0 if cit_offshore == 0

	collapse (sum) employees, by(year top1)
	
	reshape wide employees, i(year) j(top1)
	
	gen sh = employees1/(employees0 + employees1)
	
	twoway scatter sh year, c(l) ylabel(0(.1).5) ytitle("Share of total employment from top 1% offshore firms", size(small))
	graph export "${figures}/descriptive_stats/top10_part.png", as(png) replace 
	
restore
*/
