* CIT_firm_level.do
* Author: Giorgio_Thiago_Jawhar
* Date: [24_01_24]
* Purpose: Firm level analysis for Tunisia - focusing on firm-level outcomes pre and post reform.


* Loading the balanced sample dataset

use "${final}/dw2022_CIT_firmlevel.dta", clear
 
bys fid: gen unique_ind = 1 if _n==1

* Sorting data and setting panel identifiers
bys fid: egen some_inactive = min(active_firm3)		//inactive in some period
gen firm_level_sample = (balanced_firms == 1 & some_inactive == 1)
gen dummy2014 = (year >= 2014)


** Quick descriptive on balanced sample pre-reform

global descript cit_offshore foreign age d_manufacturing d_sales d_services entry_d exit_d d_employment employees d_wagebill wagebill revenue_beforetax d_loss profits d_revenue_export revenue_export  d_exportvalue exportvalue importvalue 
eststo drop *
eststo stats_balanced: quietly estpost summarize $descript if year == 2013 ,d
eststo stats_balanced1: quietly estpost summarize $descript if year == 2013 & firm_level_sample == 1 ,d
eststo stats_balanced2: quietly estpost summarize $descript if year == 2013 & cit_offshore == 1,d
eststo stats_balanced3: quietly estpost summarize $descript if year == 2013 & cit_offshore == 1 & firm_level_sample == 1 ,d

esttab stats_balanced stats_balanced1 stats_balanced2 stats_balanced3 using "${tables}/descriptive_stats/table_descriptive_balanced_updated.tex", ///
	refcat(cit_offshore "Firm Characteristics:" d_employment "Social Security Records Outcomes:" revenue_beforetax "Tax Record Outcomes:"  d_exportvalue "Customs Records Outcomes:", nolabel) ///
	cells("mean(fmt(2))" "sd(fmt(2) par)") mtitles("Full sample" "Balanced sample" "All offshore" "Balanced offshore") nonum ///
	label replace f booktabs brackets gap ///
	starlevels(* 0.1 ** 0.05 *** 0.01) collabels(none)
 

* Sorting data and setting panel identifiers
keep if firm_level_sample == 1
sort fid year
xtset fid year

***PROFIT MARGINS
recode profit_margin (min/-1 = -1) (1/max = 1), gen(profit_margin_wins)
twoway (histogram profit_margin_wins if cit_offshore == 1 & year == 2013 & inrange(profit_margin, -1, 1), fraction  width(0.02) xline(0)) ///
		(histogram profit_margin_wins if cit_offshore == 0 & year == 2013 & inrange(profit_margin, -1, 1), fraction width(0.02) fcolor(none) lcolor(red)), ///
		legend(lab(1 "Offshore") lab(2 "Onshore")) xtitle("Profit margin (winsorized)") ///
		note("Note: Distribution of winsorized profit margins for offshore and onshore firms in 2013.", size(small))
 graph export "${figures}/firm/histo_profitmg.png", replace
 
 
***** DID PROFIT MARGINS REACT IMMEDIATELY TO INCREASED TAX RATES?
 preserve
 summarize profit_margin_w if profit_margin_w == .
drop if missing(profit_margin_w)

	winsor2 profit_margin, cut(1 99)
	keep if cit_offshore == 1
	recode entry_year (2018/max = 2018), gen(entry_year_group)
	
	statsby N = r(N) mean = r(mean) ub = r(ub) lb = r(lb), by(year entry_year_group) clear: ci means profit_margin_w
	
	twoway (scatter mean year if entry_year == 2014 , c(l) lc(dknavy) mc(dknavy)) ///
			(rcap ub lb year if entry_year == 2014 , lc(dknavy)) ///
			(scatter mean year if entry_year == 2018, c(l) lc(dkgreen) mc(dkgreen)) ///
			(rcap ub lb year if entry_year == 2018 , lc(dkgreen)), xline(2013, lp(dash)) ///
		   graphregion(color(white)) legend(off) ytitle("Profit margin (winsorized)") ///
		   text(-0.05 2010 "2014 treated cohort", color(dknavy) size(small)) ///
		   text(0.3 2010  "2018+ treated cohort", color(dkgreen) size(small)) 
		  graph export "${figures}/firm/profitmargin_response.png", replace

restore

save "${final}/dw2022_CIT_firmlevel_balanced.dta", replace

****REVENUE GROWTH
sort fid year
gen revenue_growth = revenue_beforetax/L.revenue_beforetax-1
twoway (histogram revenue_growth if inrange(revenue_growth, -1,1) & year == 2013 & cit_offshore == 1) ///
       (histogram revenue_growth if inrange(revenue_growth, -1,1) & year == 2013 & cit_offshore == 0, fcolor(none) lc(red))
