use "${final}/dw2022_CIT_firmlevel_balanced.dta", clear

**********************************************************************************************************
******************************      AGGREGATES       **********************************
**********************************************************************************************************
global agg_vars "employees employees_2_or_more employees_5_or_more employees_10_or_more employees_50_or_more wagebill revenue_beforetax profits profits_w revenue_export exportvalue importvalue"

* Labeling aggregated variables
label variable employees "Employees"
label variable employees_2_or_more "Employees (2 or more)"
label variable employees_5_or_more "Employees (5 or more)"
label variable employees_10_or_more "Employees (10 or more)"
label variable employees_50_or_more "Employees (50 or more)"
label variable wagebill "Wage Bill"
label variable revenue_beforetax "Revenue Before Tax"
label variable profits "Profits"
label variable profits_w "Winsored Profits"
label variable revenue_export "Exports(Tax)"
label variable exportvalue "Exports(customs)"
label variable exportvalue "Imports(customs)"


preserve

	* Collapse data for graphing
	 
	 collapse (mean) $agg_vars , by(year cit_offshore)

	* Generate normalized variables for graphing

	sort year 
	foreach var of varlist $agg_vars {
		gen aux_`var'2013 = `var' if year == 2013
		bys cit_offshore: egen aux_ref = max(aux_`var'2013)
		gen `var'_norm = `var'/aux_ref
		drop aux_ref
	}

	sort year
/*
	* Generate graphs for each variable
	foreach var of varlist $agg_vars {

	twoway (scatter `var'_norm year if cit_offshore == 1 , c(l) lc(dknavy) mc(dknavy)) ///
		   (scatter `var'_norm year if cit_offshore == 0, c(l) lc(dkgreen) mc(dkgreen)), xline(2013, lp(dash)) ///
		   graphregion(color(white)) legend(lab(1 "Offshore") lab(2 "Onshore")) 
		   graph export "${figures}/firm/agg/`var'.png", replace
		
	   twoway (scatter `var' year if cit_offshore == 1 , c(l) lc(dknavy) mc(dknavy)) ///
	   (scatter `var' year if cit_offshore == 0, c(l) lc(dkgreen) mc(dkgreen)), xline(2013, lp(dash)) ///
	   graphregion(color(white)) legend(lab(1 "Offshore") lab(2 "Onshore"))
	   graph export "${figures}/firm/agg/levels_`var'.png", replace
	}

	* Restore data to original state
	*/
restore 



**********************************************************************************************************
******************************      REGRESSION FIGURES AND TABLES       **********************************
**********************************************************************************************************

**********************************************************************************************************
****************************** *******************     UNWEIGHTED       **********************************
**********************************************************************************************************
 

***TWO WAY FE
global reg_vars "ln_employees employees_2_or_more employees_5_or_more employees_10_or_more ln_output ln_wb ln_prof_w ln_prof ln_impv"

* Labeling variables
label variable employees "Employees"
label variable ln_employees "Log of Employees"
label variable ihs_employees "Inverse Hyperbolic Sine of Employees"
label variable employees_2_or_more "Employees (2 or more)"
label variable employees_5_or_more "Employees (5 or more)"
label variable employees_10_or_more "Employees (10 or more)"
label variable employees_50_or_more "Employees (50 or more)"
label variable ln_output "Log of Output"
label variable ln_wb "Log of Wage Bill"
label variable ln_expv "Log of Export(custom)"
label variable ln_impv "Log of Imports(custom)"
label variable ln_revenueEXP "Log of Export(tax)"
label variable ln_prof_w "Log of Winsored Profits"
label variable ln_prof "Log of Profits" 

** FIGURES
foreach var in $reg_vars {
local var_label : variable label `var'
	cap est drop *
	 qui eststo:  reghdfe `var' ib2013.year##cit_offshore 						  , a(fid ind2dig##i.year) cluster(fid)
	 qui eststo:  reghdfe `var' ib2013.year##cit_offshore if sector_group_num == 2, a(fid ind2dig##i.year) cluster(fid)
 
	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing")) ///

	 graph export "${figures}/firm/did_firm_`var'.png", replace
}

 

**********************************************************************************************************
****************************** *******************     WEIGHTED       **********************************
**********************************************************************************************************
	   
* Define treatment as simply offshore & year>= 2014
	
gen treat=0 

replace treat = 1 if year>= 2014 & cit_offshore == 1
 	 
* re-weighting control group 
*categorical  variables to use as "blocks" in pre-reform year (2009):
*quintiles of revenue, two-digit sector

*ensure stata doesnt mess up with approx

format revenue_beforetax %13.0g

xtile _quantiles2009 = revenue_beforetax if year == 2009, nq(5)

bys fid: egen quantiles2009 = mean(_quantiles2009)

* Assuming firms do not change 2dig industry (to check)
bys fid: gen check = ind2dig != ind2dig[_n-1] if _n>1 
tab check if year >= 2013
drop check

egen bin = group(quantiles2009 ind2dig)

bys fid: egen treat_constant = max(treat)
tab year treat_constant   // Now that's correct

gen unit = 1 

* We will compute shares of bins for treatment group 

preserve 

	keep if treat_constant == 1 & year == 2009

	collapse (sum) unit, by (bin) 
	egen total_obs = total(unit)
	gen share_groups = unit/total_obs 

	summ share_groups, d
	assert `r(sum)' > 0.999 & `r(sum)' < 1.001   // group weights sum to 100%

	keep bin share_groups
	tempfile treat 
	save "treat.dta", replace 

restore

merge m:1 bin using "treat.dta"

tab bin if _merge == 1 // Bins for which we cannot find equivalent bin in treated data
tab ind2dig if _merge == 1 // sectors for which we cannot find equivalent bin in treated data

drop _merge 

bys bin year treat_constant : gen count_group = _N

gen firm_weight = share_groups/count_group

total firm_weight, over(year treat_constant)

gen log_revenue = log(revenue_beforetax)

* checking: firms look more similar in size after weights

twoway (kdensity log_revenue if treat_constant == 1 & year == 2012) (kdensity log_revenue if treat_constant == 0 & year == 2012), legend(lab (1 "Treated") lab (2 "Non-treated")) graphregion (color(white)) 
graph export "${figures}/firm/kdensity_not_weighted.png" , replace
twoway (kdensity log_revenue if treat_constant == 1 & year == 2012 [w= firm_weight]) (kdensity log_revenue if treat_constant == 0 & year == 2012 [w= firm_weight]), legend(lab (1 "Treated") lab (2 "Non-treated")) graphregion (color(white)) 
graph export "${figures}/firm/kdensity_weighted.png" , replace



************************* WEIGHTED DID RESULTS  *************************
global reg_vars "ln_employees employees_2_or_more employees_5_or_more employees_10_or_more ln_output ln_wb ln_prof_w ln_prof"

**** FIGURES
foreach var in $reg_vars {
local var_label : variable label `var'

	cap est drop *
	qui eststo:  reghdfe `var' ib2013.year##cit_offshore 						  [w= firm_weight], a(fid ind2dig##i.year) cluster(fid)
	qui eststo:  reghdfe `var' ib2013.year##cit_offshore if sector_group_num == 2 [w= firm_weight], a(fid ind2dig##i.year) cluster(fid)
 
	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing")) ///

	 graph export "${figures}/firm/did_firm_w_`var'.png", replace
}
 
 
 
 
 **********************************************************************************************************
******************************   UNWEIGHTED ONLY IMMEDIATE       **********************************
**********************************************************************************************************
	 
preserve
	
	drop if (cit_offshore == 1 & entry_year != 2014)				//1000 firms offshore & 700 offshore manuf
	
	**** TABLE**** FIGURES
	foreach var in $reg_vars {
	local var_label : variable label `var'
		cap est drop *
		qui eststo:  reghdfe `var' ib2013.year##cit_offshore 						 , a(fid ind2dig##i.year) cluster(fid)
		qui eststo:  reghdfe `var' ib2013.year##cit_offshore if sector_group_num == 2, a(fid ind2dig##i.year) cluster(fid)
	 
		coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
			coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
			2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
			2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
			2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
			graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing")) ///

		 graph export "${figures}/firm/immediate/did_firm_immediate_`var'.png", replace
	}

restore


 **********************************************************************************************************
******************************   ONLY KEEP ONSHORE EXPORTERS       **********************************
**********************************************************************************************************
	 
preserve
	
	bys fid: egen high_export = max(revenue_export)   //1000 firms offshore & 700 offshore manuf
	gen exporter = high_export >0 & high_export !=.
	
	drop if cit_offshore == 0 & exporter == 0				//9335 firms (6800 onshore and 2500 offshore)
	
	
	**** TABLE**** FIGURES
	foreach var in $reg_vars {
	local var_label : variable label `var'
		cap est drop *
		qui eststo:  reghdfe `var' ib2013.year##cit_offshore 						 , a(fid ind2dig##i.year) cluster(fid)
		qui eststo:  reghdfe `var' ib2013.year##cit_offshore if sector_group_num == 2, a(fid ind2dig##i.year) cluster(fid)
	 
		coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
			coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
			2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
			2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
			2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
			graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing")) 
		 graph export "${figures}/firm/exportonly/did_firm_exportonly_`var'.png", replace
	}
	
restore



 **********************************************************************************************************
******************************   DROP FOREIGN OWNED FIRMS      **********************************
**********************************************************************************************************
	 
preserve
	
	drop if foreign == 1				//19360 firms (17,810 onshore and 1,550 offshore)
	
	
	**** TABLE**** FIGURES
	foreach var in $reg_vars {
	local var_label : variable label `var'

		cap est drop *
		qui eststo:  reghdfe `var' ib2013.year##cit_offshore 						 , a(fid ind2dig##i.year) cluster(fid)
		qui eststo:  reghdfe `var' ib2013.year##cit_offshore if sector_group_num == 2, a(fid ind2dig##i.year) cluster(fid)
	 
		coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
			coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
			2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
			2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
			2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
			graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing")) 

		 graph export "${figures}/firm/NonForeign/did_firm_onforeign_`var'.png", replace
	}
	
restore
*********************************************************************************
*************** regional ********************************************************




** prepare data for Regional fixed effects 
destring gouvernorat, replace
gen region2dig = group(gouvernorat)

destring delegation, replace
gen region4dig = group(delegation)


** FIGURES
foreach var in $reg_vars {
local var_label : variable label `var'
	cap est drop *
	 qui eststo:  reghdfe `var' ib2013.year##cit_offshore 						, a(fid ind2dig##i.year) cluster(fid)
	 qui eststo:  reghdfe `var' ib2013.year##cit_offshore						, a(fid ind2dig##i.year i.region2dig#i.year) cluster(fid)
	 qui eststo:  reghdfe `var' ib2013.year##cit_offshore       				, a(fid ind2dig##i.year i.region4dig#i.year) cluster(fid)
 
	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Original") lab(4 "region2dig") lab(6 "region4dig")) 
		
	 graph export "${figures}/firm/regional/did_firm_`var'_regional.png", replace
}



