***PROPENSITY SCORE
use "${final}/dw2022_CIT_firmlevel_balanced.dta", clear

xtile deciles_rev_2009 = revenue_beforetax if year == 2009, nq(10)
xtile deciles_emp_2009 = employees if year == 2009, nq(10)
destring gouvernorat, gen(gouvern_num)
gen export_dummy = (revenue_export > 0 & revenue_export != .) if year == 2009

***PROBIT
qui probit cit_offshore foreign age i.ind2dig i.deciles_rev_2009 i.deciles_emp_2009 i.gouvern_num export_dummy if year == 2009
predict p_hat if year == 2009
bys fid: egen p_hat_all = mean(p_hat)


***HISTOGRAMS
twoway  (histogram p_hat if cit_offshore == 1 & year == 2009, fraction width(.01) legend(label(1 "Offshore"))) ///
		(histogram p_hat if cit_offshore == 0 & year == 2009 , fraction  width(.01) fcolor(none) lc(red) legend(label(2 "Onshore"))) ///
		
graph export "${figures}/firm/hist_phat.png", as(png) replace

twoway (histogram p_hat if cit_offshore == 1 & year == 2009  & inrange(p_hat,0.05,0.95), fraction width(.01) legend(label(1 "Offshore"))) ///
		(histogram p_hat if cit_offshore == 0 & year == 2009 & inrange(p_hat,0.05,0.95) , fraction  width(.01) fcolor(none) lc(red) legend(label(2 "Onshore"))) ///
		 
graph export "${figures}/firm/hist_phat_restrict.png", as(png) replace

 
***DEFINE IPW
gen weight = .
replace weight = 1/p_hat_all 		if cit_offshore == 1
replace weight = 1/(1 - p_hat_all)  if cit_offshore == 0
replace weight = . if !inrange(p_hat_all,0.05,0.95)			//common support

***TWO WAY FE
global reg_vars "employees ln_employees ihs_employees employees_2_or_more employees_5_or_more employees_10_or_more employees_50_or_more ln_output ln_wb ln_expv ln_revenueEXP ln_prof_w ln_prof"

** FIGURES
foreach var in $reg_vars {
	cap est drop *
	 qui eststo:  reghdfe `var' ib2013.year##cit_offshore 						   [w = weight ], a(fid ind2dig##i.year) cluster(fid)
	 qui eststo:  reghdfe `var' ib2013.year##cit_offshore if sector_group_num == 2 [w = weight ], a(fid ind2dig##i.year) cluster(fid)
 
	coefplot *, keep(*year*1.cit*) vertical yline(0) omitted base ///
		coeflabel(2009.year*1.cit_offshore = "2009" 2010.year*1.cit_offshore = "2010"  2011.year*1.cit_offshore = "2011" ///
		2012.year*1.cit_offshore = "2012" 2013.year*1.cit_offshore = "2013"  2014.year*1.cit_offshore = "2014" ///
		2015.year*1.cit_offshore = "2015" 2016.year*1.cit_offshore = "2016"  2017.year*1.cit_offshore = "2017" ///)
		2018.year*1.cit_offshore = "2018" 2019.year*1.cit_offshore = "2019") ytitle("Coefficient") ///
		graphregion(color(white)) legend(lab(2 "Full") lab(4 "Manufacturing"))
	 graph export "${figures}/firm/PSM/did_firm_`var'.png", replace
}


