* CIT_Tunisia_datacleaning.do
* Author: Giorgio_Thiago_Jawhar
* Date: [20_09_24]
* Purpose: generate synthetic dataset.


******************************************************************************************
********************** unique firm ids and characteristics********************************

* Clear the existing data and set the number of observations
	clear
	set obs 15471
	set seed 12345
* Generate firm identifiers formatted as strings
	gen entident = string(_n, "%08.0f")
	gen ndgcf = string(runiformint(1,99999999), "%08.0f")

	*gen statut = runiformint(1,4)

	gen AgeE = runiformint(18,100)

* Generate a uniform random number for each observation
	gen random = runiform()

* Assign firm 'statut' : private, public , administration , and association  
	gen statut = "4"  
	replace statut = "3" if random < 0.9997
	replace statut = "2" if random < 0.9917
	replace statut = "1" if random < 0.9866

* setting up 'fj' : firm legal form : 
	gen fj = "99"  
		replace fj = "22" if runiform() < 0.2
		replace fj = "21" if runiform() < 0.0093
		replace fj = "13" if runiform() < 0.0029
		replace fj = "23" if runiform() < 0.0222
		replace fj = "70" if runiform() < 0.0058
		replace fj = "90" if runiform() < 0.0021
		replace fj = "10" if runiform() < 0.0008
		replace fj = "60" if runiform() < 0.0020
		replace fj = "66" if runiform() < 0.0020
		replace fj = "11" if runiform() < 0.0004
		replace fj = "98" if runiform() < 0.0013
		replace fj = "20" if runiform() < 0.0004
		replace fj = "30" if runiform() < 0.0005
		replace fj = "40" if runiform() < 0.0002
		replace fj = "41" if runiform() < 0.0001
		replace fj = "84" if runiform() < 0.0001
		replace fj = "80" if runiform() < 0.0002
		replace fj = "82" if runiform() < 0.0001
		replace fj = "86" if runiform() < 0.0001
		replace fj = "97" if runiform() < 0.0001
		replace fj = "29" if runiform() < 0.0001
		replace fj = "32" if runiform() < 0.0001
		replace fj = "50" if runiform() < 0.0001
		replace fj = "64" if runiform() < 0.0001
		replace fj = "62" if runiform() < 0.0001
		replace fj = "72" if runiform() < 0.0001

* Assign firm 'nationalite' 
	gen nationalite = "002" if random < 0.0164
	replace nationalite = "000" if random < 0.0002
	replace nationalite = "001" if missing(nationalite)

* Generate a uniform random number for each observation
	gen u = runiform()

* Assign 'rid' : tax regime 
	gen rid = "9" if u < 0.9998
		replace rid = "8" if u < 0.99658
		replace rid = "6" if u < 0.9658
		replace rid = "5" if u < 0.9375
		replace rid = "4" if u < 0.9352
		replace rid ="3" if u < 0.6065
		replace rid = "2" if u < 0.6017
		replace rid = "1" if u < 0.0147
		replace rid = "0" if u < 0.0008
		
* regional var 
	gen Gouvernorat = string(runiformint(1,24), "%02.0f")
	gen Gouvernorat_r = string(runiformint(51,62), "%02.0f")

	gen Delegation = Gouvernorat + Gouvernorat_r

	gen NAT09_2ch = string(runiformint(1,99), "%02.0f")
	gen NAT09_2ch_r = string(runiformint(1,99), "%02.0f")

	gen NAT09 = NAT09_2ch + NAT09_2ch_r
	gen NAT09_3ch = substr(NAT09,3,1)
	
* Create the region variable
	gen uniform = runiform()
	gen region = ""

* Assign regions based on the cumulative distribution
	replace region = "CENTRE EST" if uniform < 0.2406
	replace region = "CENTRE OUEST" if uniform >= 0.2406 & uniform < 0.3205
	replace region = "NORD EST" if uniform >= 0.3205 & uniform < 0.7974
	replace region = "NORD OUEST" if uniform >= 0.7974 & uniform < 0.8831
	replace region = "SUD EST" if uniform >= 0.8831 & uniform < 0.9579
	replace region = "SUD OUEST" if uniform >= 0.9579
******************************************************************************************
******************************* Panel structure ******************************************

* Generate entry year
	gen entry_year = floor(1996 + (2021 - 1996 + 1) * runiform())

* Generate exit year based on a probability (e.g., 50% chance to exit before 2021)
	gen exit_year = cond(runiform() < 0.5, floor(entry_year + (2021 - entry_year + 1) * runiform()), 2021)

* Expand dataset for each year a firm could be active
	gen long id = _n
	expand 26
	bysort id: gen annee = entry_year + _n - 1

* Ensure years are within the entry and exit year
	bysort id: replace annee = . if annee > exit_year | annee > 2021

* Drop non-operational years
	drop if missing(annee)


* Validate the final structure
	tabulate annee

	order entident annee 
	gsort entident annee 

	xtset id annee


    bys id: gen lag_year = l.annee
	bys id: gen lead_year = f.annee

	gen firm_status = ""

**Identifying entrants

	replace firm_status = "entrant" if missing(lag_year) & !missing(annee) 

**Identifying exiters

	replace firm_status = "exiter" if !missing(lag_year) & missing(lead_year) & annee!= 2021


** entry and exit based on presence in previous year 

	gen Nentry = ""
	replace Nentry = "1" if firm_status == "entrant"
	gen Exit = ""
	replace Exit = "1" if firm_status == "exiter"

*******************************************************************************************
*************** Administrative data ******************************************************

** generate social security data 

	gen MoyenneS = runiformint(0,19179)
	gen Masse_Salariale = runiformint(1,2.489e+11)

** generate customs data 
	gen ExportV = runiformint(1,2.74e+09)
	gen ExportP = runiformint(1,3.26e+09)
	gen ImportV = runiformint(1,6.35e+09)
	gen ImportP = runiformint(1,3.99e+09)


**generate tax data


	gen CA_TTC_DT  = runiformint(1,7.29e+09)
	gen CA_Local_DT  = runiformint(1,5.47e+09)
	gen CA_Export_DT  = runiformint(1,2.96e+09)
	gen CA_HT_DT = CA_Local_DT + CA_Export_DT 
	gen ResultatALL_DT  = runiformint(-9.33e+09,1.13e+09)


** not used vars for code comp

	gen d_ouv = ""
	gen c_actp = ""
	gen nat96 = ""
	gen Apen96 = ""
	gen Apenpub09 = ""
	gen TrancheS = ""
	gen CodResult = ""
	gen RevenuPP_DT = .
	gen ResultatPM_DT = .
	
	
	gen Apen09 = ""
	gen njc = .

	gen EffectifST1 = .
	gen EffectifST2 = .
	gen EffectifST3 =.
	gen EffectifST4 =.
	
	// Generate random values between 0 and 10 for each variable
replace EffectifST1 = runiform() * 10
replace EffectifST2 = runiform() * 10
replace EffectifST3 = runiform() * 10
replace EffectifST4 = runiform() * 10



	**organise the dataset


keep entident annee ndgcf AgeE statut fj nationalite rid Gouvernorat Delegation ///
NAT09_2ch NAT09 Apen09 NAT09_3ch region Nentry Exit MoyenneS Masse_Salariale ExportV ExportP ///
ImportV ImportP CA_TTC_DT CA_Local_DT CA_Export_DT CA_HT_DT ResultatALL_DT d_ouv c_actp ///
nat96 Apen96 Apenpub09 TrancheS CodResult RevenuPP_DT ResultatPM_DT njc EffectifST1 EffectifST2 EffectifST3 EffectifST4

order entident ndgcf d_ouv annee Nentry Exit statut fj rid nationalite c_actp nat96 ///
Apen96 NAT09 Apen09 Apenpub09 Delegation Gouvernorat MoyenneS TrancheS Masse_Salariale ///
ExportV ExportP ImportV ImportP CodResult CA_TTC_DT CA_Local_DT CA_Export_DT CA_HT_DT ///
RevenuPP_DT ResultatPM_DT ResultatALL_DT AgeE njc NAT09_2ch NAT09_3ch region

* label varibles

label variable entident			 "Firm ID"
label variable ndgcf	 		 "Tax ID"
label variable d_ouv 			 "Opening date"
label variable annee	 		 "Years"
label variable statut	 		 "Firm status"
label variable fj		 		 "Firm legal form"
label variable rid		 		 "Firm tax regime"
label variable nationalite		 "Firm nationality"

label variable c_actp		 	 "DGI classification"
label variable nat96		 	 "NAT 1996 classification"
label variable Apen96		 	 "NAT 1996 classification 2dig"
label variable NAT09		 	 "NAT 2009 classification"
label variable Apen09		 	 "NAT 2009 classification 2dig"
label variable Apenpub09		 "NAT 2009 classification aggregated by the INS"
label variable Delegation		 "Administrative delegation"
label variable Gouvernorat		 "Administrative governorate"

label variable ImportV	 		 "Customs import value"
label variable ExportV		 	 "Customs export value"
label variable MoyenneS 		 "Average number of employees"
label variable TrancheS 		 "Employees groups"
label variable Masse_Salariale 	 "Wage bill"
label variable AgeE 			 "Firm age"
label variable Nentry 			 "Entry dummy"
label variable Exit 			 "Exit dummy"
label variable ExportP		 	 "Customs export quantity"
label variable ImportP		 	 "Customs import quantity"
label variable CodResult		 "Profits dummy"

label variable CA_TTC_DT		 "Total Revenue"
label variable CA_Local_DT		 "Local Revenue"
label variable CA_Export_DT		 "Exports Revenue"
label variable CA_HT_DT		     "Revenue Excluding Tax"

label variable RevenuPP_DT		 "Income if the firm is a natural person"
label variable ResultatPM_DT	 "Revenu if the the firm is juridical person"
label variable ResultatALL_DT	 "Net profits"

label variable njc	 		     "Net job creation"
label variable NAT09_2ch	     "NAT 2 dig"
label variable NAT09_3ch	     "NAT 3 dig"
label variable region	         "Region"







